set IMAGE_ 257
set PHYSICAL_ 258
set AMPLIFIER_ 259
set DETECTOR_ 260
set WCS_ 261
set WCSA_ 262
set WCSB_ 263
set WCSC_ 264
set WCSD_ 265
set WCSE_ 266
set WCSF_ 267
set WCSG_ 268
set WCSH_ 269
set WCSI_ 270
set WCSJ_ 271
set WCSK_ 272
set WCSL_ 273
set WCSM_ 274
set WCSN_ 275
set WCSO_ 276
set WCSP_ 277
set WCSQ_ 278
set WCSR_ 279
set WCSS_ 280
set WCST_ 281
set WCSU_ 282
set WCSV_ 283
set WCSW_ 284
set WCSX_ 285
set WCSY_ 286
set WCSZ_ 287
set INT_ 288
set REAL_ 289
set STRING_ 290
set BLEND_ 291
set CLEAR_ 292
set CLOSE_ 293
set COLOR_ 294
set DARKEN_ 295
set LIGHTEN_ 296
set LOAD_ 297
set MARK_ 298
set NAN_ 299
set NONNAN_ 300
set NONZERO_ 301
set OPEN_ 302
set RANGE_ 303
set SOURCE_ 304
set SYSTEM_ 305
set TRANSPARENCY_ 306
set ZERO_ 307
